@@ -80,7 +80,6 @@ from .MenuList import MenuList
 from .MobileStepper import MobileStepper
 from .Modal import Modal
 from .ModalUnstyled import ModalUnstyled
-from .MuiThemeProvider import MuiThemeProvider
 from .NativeSelect import NativeSelect
 from .NoSsr import NoSsr
 from .OutlinedInput import OutlinedInput
@@ -106,6 +105,7 @@ from .SnackbarContent import SnackbarContent
 from .SpeedDial import SpeedDial
 from .SpeedDialAction import SpeedDialAction
 from .SpeedDialIcon import SpeedDialIcon
+from .Stack import Stack
 from .Step import Step
 from .StepButton import StepButton
 from .StepConnector import StepConnector
@@ -223,7 +223,6 @@ __all__ = [
     "MobileStepper",
     "Modal",
     "ModalUnstyled",
-    "MuiThemeProvider",
     "NativeSelect",
     "NoSsr",
     "OutlinedInput",
@@ -249,6 +248,7 @@ __all__ = [
     "SpeedDial",
     "SpeedDialAction",
     "SpeedDialIcon",
+    "Stack",
     "Step",
     "StepButton",
     "StepConnector",
